@@ -1,5 +1,4 @@
-from easy_spark.easy_delta_helpers import EasyDeltaHelpers
-from easy_spark.table_path import TablePath
+from easy_spark.easy_spark_delta_helpers import EasySparkDeltaHelpers
 
 
 class EasySQLSelectBuilder:
@@ -11,23 +10,20 @@ class EasySQLSelectBuilder:
         self.sql += " " + ", ".join(columns)
         return self
 
-    def from_table(self, table: str) -> 'EasySQLSelectBuilder':
+    def from_table_name(self, table: str) -> 'EasySQLSelectBuilder':
         self.sql += f" FROM {table}"
         return self
 
-    def from_lh_table(self, name: str, table: str) -> 'EasySQLSelectBuilder':
-        self.sql += f" FROM {name}.{table}"
+    def from_lh_table_name(self, name: str, table_name: str) -> 'EasySQLSelectBuilder':
+        self.sql += f" FROM {name}.{table_name}"
         return self
 
     def from_path(self, path: str) -> 'EasySQLSelectBuilder':
         self.sql += f" FROM delta.`{path}`"
         return self
 
-    def from_table_path(self, path: TablePath) -> 'EasySQLSelectBuilder':
-        return self.from_path(path.path)
-
     def where(self, keys: dict[str, any]) -> 'EasySQLSelectBuilder':
-        conditions = EasyDeltaHelpers.build_condition(keys)
+        conditions = EasySparkDeltaHelpers.build_condition(keys)
 
         self.sql += f" WHERE {conditions}"
         return self
@@ -36,6 +32,11 @@ class EasySQLSelectBuilder:
         self.sql += f" WHERE {condition}"
         return self
 
+    def limit(self, limit: int) -> 'EasySQLSelectBuilder':
+        if limit:
+            self.sql += f" LIMIT {limit}"
+        return self
+
     @staticmethod
     def new() -> 'EasySQLSelectBuilder':
         return EasySQLSelectBuilder()
